# In brevi

**dawgdad** is a Python library for data scientists, machine learning engineers, and statisticians. It contains statistical and graphical functions for making sense of data to create information and understanding.

- Supervised machine learning
- Six Sigma methodology
- Regular expressions
- Process capability
- Process variation
- Excel file edits
- Taguchi Methods
- Data Science
- Automation
- Analytics

Why **dawgdad**?

- Equivalent Python functions that are available in R, SAS, JMP, Minitab
- Other packages have limited process control analysis features
- Other packages are abandoned or inadequately supported
- Functions to support measurement system analysis
- Functions to simplify statistics, graphs, etc.
- Functions to support process control charts
- Functions to support SQL functionality
- Develop a free open source package

# Documentation

Full documentation is available at [https://dawgdad.readthedocs.io/en/latest/](https://dawgdad.readthedocs.io/en/latest/).

# References

To cite this repository, please use:

@software{dawgdad,
  author  = {Gilles Pilon},
  title   = {dawgdad},
  url     = {https://github.com/gillespilon/dawgdad},
  version = {1.0.5},
  date    = {2025-02-28}
}
